@@ -268,17 +268,19 @@ class InteractiveBase(GenericJob):
 
     def interactive_open(self):
         """
+        Set the run mode to interactive.
 
-        Returns:
+        This is the same as setting :attribute:`.server.run_mode.interactive`.
 
+        Must be called before :method:`.run()` is called.
         """
         self.server.run_mode.interactive = True
 
     def interactive_close(self):
         """
+        Stop interactive execution and sync interactive output cache.
 
-        Returns:
-
+        Sets the job status to :attribute:`~.JobStatus.finished`, :method:`.run()` cannot be called after this.
         """
         if (
             len(list(self.interactive_cache.keys())) > 0
