@@ -43,6 +43,7 @@ from pyiron_base.server.queuestatus import (
     queue_check_job_is_waiting_or_running,
 )
 from pyiron_base.job.external import Notebook
+from pyiron_base.project.data import ProjectData
 
 from pyiron_base.archiving import import_archive, export_archive
 
@@ -74,53 +75,31 @@ class Project(ProjectPath):
                                     directory.
 
     Attributes:
+        root_path (): The pyiron user directory, defined in the .pyiron configuration.
+        project_path (): The relative path of the current project / folder starting from the root path of the pyiron
+                            user directory
+        path (): The absolute path of the current project / folder.
+        base_name (): The name of the current project / folder.
+        history (): Previously opened projects / folders.
+        parent_group (): Parent project - one level above the current project.
+        user (): Current unix/linux/windows user who is running pyiron
+        sql_query (): An SQL query to limit the jobs within the project to a subset which matches the SQL query.
+        db (): Connection to the SQL database.
+        job_type (): Job Type object with all the available job types: ['ExampleJob', 'SerialMaster', 'ParallelMaster',
+                        'ScriptJob', 'ListMaster'].
+        view_mode (): If viewer_mode is enable pyiron has read only access to the database.
+        data (pyiron_base.project.data.ProjectData): A storage container for project-level data.
 
-        .. attribute:: root_path
-
-            the pyiron user directory, defined in the .pyiron configuration
-
-        .. attribute:: project_path
-
-            the relative path of the current project / folder starting from the root path
-            of the pyiron user directory
-
-        .. attribute:: path
-
-            the absolute path of the current project / folder
-
-        .. attribute:: base_name
-
-            the name of the current project / folder
-
-        .. attribute:: history
-
-            previously opened projects / folders
-
-        .. attribute:: parent_group
-
-            parent project - one level above the current project
-
-        .. attribute:: user
-
-            current unix/linux/windows user who is running pyiron
-
-        .. attribute:: sql_query
-
-            an SQL query to limit the jobs within the project to a subset which matches the SQL query.
-
-        .. attribute:: db
-
-            connection to the SQL database
-
-        .. attribute:: job_type
-
-            Job Type object with all the available job types: ['ExampleJob', 'SerialMaster', 'ParallelMaster',
-                                                               'ScriptJob', 'ListMaster']
-
-        .. attribute:: view_mode
-
-            If viewer_mode is enable pyiron has read only access to the database.
+    Examples:
 
+        Storing data:
+            >>> pr = Project('example')
+            >>> pr.data.foo = 42
+            >>> pr.data.write()
+            Some time later or in a different notebook, but in the same file location...
+            >>> other_pr_instance = Project('example')
+            >>> print(pr.data)
+            {'foo': 42}
     """
 
     def __init__(self, path="", user=None, sql_query=None, default_working_directory=False):
@@ -147,6 +126,11 @@ class Project(ProjectPath):
             self.db = FileTable(project=path)
         self.job_type = JobTypeChoice()
 
+        self._data = ProjectData(project=self, table_name="data")
+        # TODO: Read the data here, if it exists.
+        #       Currently this keeps giving a recursion error because ProjectHDFio instantiation copies the project
+        #       which then tries to read, which instantiates a ProjectHDFio, which copies the project... Ugh.
+
     @property
     def parent_group(self):
         """
@@ -189,6 +173,15 @@ class Project(ProjectPath):
     def create(self):
         return self._creator
 
+    @property
+    def data(self):
+        if len(self._data) == 0:  # This is just a workaround because loading in __init__ is not working
+            try:
+                self._data.read()
+            except KeyError:
+                pass
+        return self._data
+
     def copy(self):
         """
         Copy the project object - copying just the Python object but maintaining the same pyiron path
@@ -1460,6 +1453,8 @@ class Project(ProjectPath):
         if item in self.list_dirs():
             with self.open(item) as new_item:
                 return new_item.copy()
+        if item in os.listdir(self.path) and os.path.isdir(os.path.join(self.path, item)):
+            return self.open(item)
         raise ValueError("Unknown item: {}".format(item))
 
     def _remove_files(self, pattern="*"):
